Class: Fluent::Auditify::Plugin::ConfPluginType

Inherits:
Conf
  • Object
show all
Defined in:
lib/fluent/auditify/plugin/conf_plugin_type.rb

Instance Attribute Summary

Attributes inherited from Base

#log

Instance Method Summary collapse

Methods inherited from Conf

#artifact, #conf?, #disabled?, #file_get_contents, #file_readlines_each, #guilty, #plugin_defs, #polish, #read_with_include_directive, #surround_text, #yaml?

Constructor Details

#initializeConfPluginType

Returns a new instance of ConfPluginType.



23
24
25
# File 'lib/fluent/auditify/plugin/conf_plugin_type.rb', line 23

def initialize
  super
end

Instance Method Details

#parse(conf_path, options = {}) ⇒ Object



35
36
37
38
39
40
41
# File 'lib/fluent/auditify/plugin/conf_plugin_type.rb', line 35

def parse(conf_path, options={})
  if yaml?(conf_path)
    raise NotImplementedError
  else conf?(conf_path)
    process_conf(conf_path, options)
  end
end

#plugin_infoObject



27
28
29
30
31
32
33
# File 'lib/fluent/auditify/plugin/conf_plugin_type.rb', line 27

def plugin_info
  {
    name: 'plugin_type',
    summary: 'Detect whether wrong plugin name was specified or not',
    description: 'Detect whether wrong plugin name was specified or not in each directives. Typically it can detect the case that @type forward in filter directive.'
  }
end

#supported_file_extension?Boolean

Returns:

  • (Boolean)


19
20
21
# File 'lib/fluent/auditify/plugin/conf_plugin_type.rb', line 19

def supported_file_extension?
  [:conf]
end

#supported_platform?Boolean

Returns:

  • (Boolean)


15
16
17
# File 'lib/fluent/auditify/plugin/conf_plugin_type.rb', line 15

def supported_platform?
  :any
end